@@ -42,10 +42,11 @@ def create_origin_database_dump():
         # Run mysql dump command, e.g.
         # mysqldump --no-tablespaces -u'db' -p'db' -h'db1' -P'3306' 'db'  > /tmp/_db_08-10-2021_07-00.sql
         mode.run_command(
-            helper.get_command('origin', 'mysqldump') + ' ' + _mysqldump_options +
-            database_utility.generate_mysql_credentials('origin') + ' \'' +
-            system.config['origin']['db']['name'] + '\' ' +
+            helper.get_command(mode.Client.ORIGIN, 'mysqldump') + ' ' + _mysqldump_options +
+            database_utility.generate_mysql_credentials(mode.Client.ORIGIN) + ' \'' +
+            system.config[mode.Client.ORIGIN]['db']['name'] + '\' ' +
             database_utility.generate_ignore_database_tables() +
+            database_utility.get_database_tables() +
             ' > ' + _dump_file_path,
             mode.Client.ORIGIN,
             skip_dry_run=True
@@ -72,6 +73,8 @@ def import_database_dump():
         )
         clear_database(mode.Client.TARGET)
 
+    database_utility.truncate_tables()
+
     if not system.config['keep_dump'] and not mode.is_dump():
 
         database_utility.get_database_version(mode.Client.TARGET)
@@ -112,9 +115,17 @@ def import_database_dump():
             f'Importing after_dump file {output.CliFormat.BLACK}{_after_dump}{output.CliFormat.ENDC}',
             True
         )
-
         import_database_dump_file(mode.Client.TARGET, _after_dump)
 
+    if 'post_sql' in system.config['target']:
+        output.message(
+            output.Subject.TARGET,
+            f'Running addition post sql commands',
+            True
+        )
+        for _sql_command in system.config['target']['post_sql']:
+            database_utility.run_database_command(mode.Client.TARGET, _sql_command, True)
+
 
 def import_database_dump_file(client, filepath):
     """
