@@ -37,11 +37,12 @@ config = {
     'use_sshpass': False,
     'ssh_agent': False,
     'ssh_password': {
-        'origin': None,
-        'target': None
+        mode.Client.ORIGIN: None,
+        mode.Client.TARGET: None
     },
     'link_target': None,
     'link_origin': None,
+    'tables': ''
 }
 
 #
@@ -63,25 +64,22 @@ def check_target_configuration():
     parser.get_database_configuration(mode.Client.TARGET)
 
 
-def get_configuration(host_config):
+def get_configuration(host_config, args):
     """
     Checking configuration information by file or dictionary
     :param host_config: Dictionary
+    :param args: Dictionary
     :return:
     """
     global config
-
-    if config['config_file_path'] is None and host_config == {}:
-        sys.exit(
-            output.message(
-                output.Subject.ERROR,
-                f'Configuration is missing, use a separate file or provide host parameter',
-                False
-            )
-        )
+    config[mode.Client.TARGET] = {}
+    config[mode.Client.ORIGIN] = {}
 
     if host_config:
-        config.update(host_config)
+        if type(host_config) is dict:
+            config.update(host_config)
+        else:
+            config.update(json.dumps(host_config))
 
     _config_file_path = config['config_file_path']
     if not _config_file_path is None:
@@ -115,28 +113,145 @@ def get_configuration(host_config):
                 )
             )
 
+    args_config = build_config(args)
+
+    if config['config_file_path'] is None and args_config == {}:
+        sys.exit(
+            output.message(
+                output.Subject.ERROR,
+                f'Configuration is missing, use a separate file or provide host parameter',
+                False
+            )
+        )
+
     validation.check(config)
     check_options()
     helper.run_script(script='before')
     log.get_logger().info('Starting db_sync_tool')
 
 
+def build_config(args):
+    """
+    ADding the provided arguments
+    :param args:
+    :return:
+    """
+    if args is None:
+        return
+
+    if not args.type is None:
+        config['type'] = args.type
+
+    if not args.tables is None:
+        config['tables'] = args.tables
+
+    if not args.origin is None:
+        config['link_origin'] = args.origin
+
+    if not args.target is None:
+        config['link_target'] = args.target
+
+    if not args.target_path is None:
+        config[mode.Client.TARGET]['path'] = args.target_path
+
+    if not args.target_name is None:
+        config[mode.Client.TARGET]['name'] = args.target_name
+
+    if not args.target_host is None:
+        config[mode.Client.TARGET]['host'] = args.target_host
+
+    if not args.target_user is None:
+        config[mode.Client.TARGET]['user'] = args.target_user
+
+    if not args.target_password is None:
+        config[mode.Client.TARGET]['password'] = args.target_password
+
+    if not args.target_key is None:
+        config[mode.Client.TARGET]['ssh_key'] = args.target_key
+
+    if not args.target_port is None:
+        config[mode.Client.TARGET]['port'] = args.target_port
+
+    if not args.target_dump_dir is None:
+        config[mode.Client.TARGET]['dump_dir'] = args.target_dump_dir
+
+    if not args.target_db_name is None:
+        config[mode.Client.TARGET]['db']['name'] = args.target_db_name
+
+    if not args.target_db_host is None:
+        config[mode.Client.TARGET]['db']['host'] = args.target_db_host
+
+    if not args.target_db_user is None:
+        config[mode.Client.TARGET]['db']['user'] = args.target_db_user
+
+    if not args.target_db_password is None:
+        config[mode.Client.TARGET]['db']['password'] = args.target_db_password
+
+    if not args.target_db_port is None:
+        config[mode.Client.TARGET]['db']['port'] = args.target_db_port
+
+    if not args.target_after_dump is None:
+        config[mode.Client.TARGET]['after_dump'] = args.target_after_dump
+
+    if not args.origin_path is None:
+        config[mode.Client.ORIGIN]['path'] = args.origin_path
+
+    if not args.origin_name is None:
+        config[mode.Client.ORIGIN]['name'] = args.origin_name
+
+    if not args.origin_host is None:
+        config[mode.Client.ORIGIN]['host'] = args.origin_host
+
+    if not args.origin_user is None:
+        config[mode.Client.ORIGIN]['user'] = args.origin_user
+
+    if not args.origin_password is None:
+        config[mode.Client.ORIGIN]['password'] = args.origin_password
+
+    if not args.origin_key is None:
+        config[mode.Client.ORIGIN]['ssh_key'] = args.origin_key
+
+    if not args.origin_port is None:
+        config[mode.Client.ORIGIN]['port'] = args.origin_port
+
+    if not args.origin_dump_dir is None:
+        config[mode.Client.ORIGIN]['dump_dir'] = args.origin_dump_dir
+
+    if not args.origin_db_name is None:
+        config[mode.Client.ORIGIN]['db']['name'] = args.origin_db_name
+
+    if not args.origin_db_host is None:
+        config[mode.Client.ORIGIN]['db']['host'] = args.origin_db_host
+
+    if not args.origin_db_user is None:
+        config[mode.Client.ORIGIN]['db']['user'] = args.origin_db_user
+
+    if not args.origin_db_password is None:
+        config[mode.Client.ORIGIN]['db']['password'] = args.origin_db_password
+
+    if not args.origin_db_port is None:
+        config[mode.Client.ORIGIN]['db']['port'] = args.origin_db_port
+
+    return config
+
+
 def check_options():
     """
     Checking configuration provided file
     :return:
     """
     global config
-    if 'dump_dir' in config['origin']:
+    if 'dump_dir' in config[mode.Client.ORIGIN]:
         config['default_origin_dump_dir'] = False
 
-    if 'dump_dir' in config['target']:
+    if 'dump_dir' in config[mode.Client.TARGET]:
         config['default_target_dump_dir'] = False
 
     if 'check_dump' in config:
         config['check_dump'] = config['check_dump']
 
     link_configuration_with_hosts()
+    reverse_hosts()
     mode.check_sync_mode()
 
 
@@ -237,7 +352,8 @@ def check_args_options(config_file=None,
                        clear=False,
                        force_password=False,
                        use_rsync=False,
-                       use_rsync_options=None):
+                       use_rsync_options=None,
+                       reverse=False):
     """
     Checking arguments and fill options array
     :param config_file:
@@ -253,6 +369,7 @@ def check_args_options(config_file=None,
     :param force_password:
     :param use_rsync:
     :param use_rsync_options:
+    :param reverse:
     :return:
     """
     global config
@@ -297,12 +414,17 @@ def check_args_options(config_file=None,
 
     if not use_rsync is None:
         config['use_rsync'] = use_rsync
-        helper.check_rsync_version()
-        helper.check_sshpass_version()
+
+        if use_rsync is True:
+            helper.check_rsync_version()
+            helper.check_sshpass_version()
 
         if not use_rsync_options is None:
             config['use_rsync_options'] = use_rsync_options
 
+    if not reverse is None:
+        config['reverse'] = reverse
+
     if not keep_dump is None:
         default_local_sync_path = keep_dump
 
@@ -318,48 +440,86 @@ def check_args_options(config_file=None,
         )
 
 
+def reverse_hosts():
+    """
+    Checking authorization for clients
+    :return:
+    """
+    if config['reverse']:
+        _origin = config[mode.Client.ORIGIN]
+        _target = config[mode.Client.TARGET]
+
+        config[mode.Client.ORIGIN] = _target
+        config[mode.Client.TARGET] = _origin
+
+        output.message(
+            output.Subject.INFO,
+            'Reverse origin and target hosts',
+            True
+        )
+
+
 def link_configuration_with_hosts():
     """
     Merging the hosts definition with the given configuration file
     @ToDo Simplify function
     :return:
     """
-    if ('link' in config['origin'] or 'link' in config['target']) and config['link_hosts'] == '':
-        # Try to find default hosts.json file in same directory
-        sys.exit(
-            output.message(
-                output.Subject.ERROR,
-                f'Missing hosts file for linking hosts with configuration. '
-                f'Use the "-o" / "--hosts" argument to define the filepath for the hosts file, '
-                f'when using a link parameter within the configuration.',
-                False
+    if ('link' in config[mode.Client.ORIGIN] or 'link' in config[mode.Client.TARGET]) and config['link_hosts'] == '':
+        #
+        # Try to read host file path from link entry
+        #
+        _host = str(config[mode.Client.ORIGIN]['link'].split('@')[0]) if 'link' in config[mode.Client.ORIGIN] else ''
+        _host = str(config[mode.Client.TARGET]['link'].split('@')[0]) if 'link' in config[mode.Client.TARGET] else _host
+
+        config['link_hosts'] = _host
+
+        if config['link_hosts'] == '':
+            # Try to find default hosts.json file in same directory
+            sys.exit(
+                output.message(
+                    output.Subject.ERROR,
+                    f'Missing hosts file for linking hosts with configuration. '
+                    f'Use the "-o" / "--hosts" argument to define the filepath for the hosts file, '
+                    f'when using a link parameter within the configuration or define the the '
+                    f'filepath direct in the link entry e.g. "host.yaml@entry1".',
+                    False
+                )
             )
-        )
 
     if config['link_hosts'] != '':
+
+        # Adjust filepath from relative to absolute
+        if config['link_hosts'][0] != '/':
+            config['link_hosts'] = os.path.dirname(os.path.abspath(config['config_file_path'])) + '/' + config['link_hosts']
+
         if os.path.isfile(config['link_hosts']):
             with open(config['link_hosts'], 'r') as read_file:
-                _hosts = json.load(read_file)
+                if config['link_hosts'].endswith('.json'):
+                    _hosts = json.load(read_file)
+                elif config['link_hosts'].endswith('.yaml') or config['link_hosts'].endswith('.yml'):
+                    _hosts = yaml.safe_load(read_file)
+
                 output.message(
                     output.Subject.INFO,
                     f'Linking configuration with hosts {output.CliFormat.BLACK}{config["link_hosts"]}{output.CliFormat.ENDC}',
                     True
                 )
                 if not config['config_file_path'] is None:
-                    if 'link' in config['origin']:
-                        _host_name = str(config['origin']['link']).replace('@', '')
+                    if 'link' in config[mode.Client.ORIGIN]:
+                        _host_name = str(config[mode.Client.ORIGIN]['link']).split('@')[1]
                         if _host_name in _hosts:
-                            config['origin'] = {**config['origin'], **_hosts[_host_name]}
+                            config[mode.Client.ORIGIN] = {**config[mode.Client.ORIGIN], **_hosts[_host_name]}
 
-                    if 'link' in config['target']:
-                        _host_name = str(config['target']['link']).replace('@', '')
+                    if 'link' in config[mode.Client.TARGET]:
+                        _host_name = str(config[mode.Client.TARGET]['link']).split('@')[1]
                         if _host_name in _hosts:
-                            config['target'] = {**config['target'], **_hosts[_host_name]}
+                            config[mode.Client.TARGET] = {**config[mode.Client.TARGET], **_hosts[_host_name]}
                 else:
                     if 'link_target' in config and 'link_origin' in config:
                         if config['link_target'] in _hosts and config['link_origin'] in _hosts:
-                            config['target'] = _hosts[config['link_target']]
-                            config['origin'] = _hosts[config['link_origin']]
+                            config[mode.Client.TARGET] = _hosts[config['link_target']]
+                            config[mode.Client.ORIGIN] = _hosts[config['link_origin']]
                         else:
                             sys.exit(
                                 output.message(
